# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify CentOS Linux and Scientific Linux as rhel
%if "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "sl" || "%{__distinit}" == "sls"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

Summary:	A library that performs asynchronous DNS operations
Name:		c-ares
Version:	1.7.5
Release:	2.0.cf.%{__distinit}%{__distvers}
License:	MIT
Group:		System Environment/Libraries
URL:		http://c-ares.haxx.se/
Source0:	http://c-ares.haxx.se/download/c-ares-%{version}.tar.gz
Patch0:		c-ares-1.7.5-optflags.patch
Patch1:		c-ares-multilib.patch
Patch10:	c-ares-1.7.5-utf8.patch
BuildRoot:	%{_tmppath}/%{name}-%{version}-%{release}-root-%(id -nu)

%description
c-ares is a C library that performs DNS requests and name resolves 
asynchronously. c-ares is a fork of the library named 'ares', written 
by Greg Hudson at MIT.

%package devel
Summary:	Development files for c-ares
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	pkgconfig

%description devel
This package contains the header files and libraries needed to
compile applications or shared objects that use c-ares.

%prep
%setup -q

# Use the appropriate compiler flags
%patch0 -p1 -b .optflags

# Fix multilib file conflict in c-ares-devel (#602880)
%patch1 -p1 -b .multilib

# Recode docs as UTF-8
%patch10 -p1 -b .utf8

%build
%configure --enable-shared --disable-static --disable-dependency-tracking
make %{?_smp_mflags}

%install
rm -rf %{buildroot}
make DESTDIR=%{buildroot} install
rm -f %{buildroot}%{_libdir}/libcares.la

%clean
rm -rf %{buildroot}

%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig

%files
%defattr(-, root, root)
%doc README README.cares CHANGES NEWS RELEASE-NOTES TODO AUTHORS
%{_libdir}/libcares.so.*

%files devel
%defattr(-,root,root,-)
%{_includedir}/ares.h
%{_includedir}/ares_build.h
%{_includedir}/ares_dns.h
%{_includedir}/ares_rules.h
%{_includedir}/ares_version.h
%{_libdir}/libcares.so
%{_libdir}/pkgconfig/libcares.pc
%{_mandir}/man3/ares_*.3*

%changelog
* Wed Jan 18 2012 Paul Howarth <paul@city-fan.org> - 1.7.5-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Wed Aug 17 2011 Paul Howarth <paul@city-fan.org> - 1.7.5-1.0.cf
- Update to 1.7.5
  - Detection of semicolon comments in resolv.conf
  - Avoid using system's inet_net_pton affected by the WLB-2008080064 advisory
  - Replacement ares_inet_net_pton affected by the WLB-2008080064 advisory
  - Replacement ares_inet_ntop affected by potential out of bounds write
  - Added install target to Makefile.msvc
  - Only fall back to AF_INET searches when looking for AF_UNSPEC addresses
  - Fixed ares_parse_*_reply memory leaks
  - Use correct sizeof in ares_getnameinfo()
  - IPv6-on-windows: find DNS servers correctly
  - man pages: docs for the c-ares utility programs
  - getservbyport replacement for Win CE
  - config_sortlist: (win32) missing else
  - advance_tcp_send_queue: avoid NULL ptr dereference
  - configure: fix a bashism
  - ares_expand_name: Fix encoded length for indirect root
- Rebase optflags patch to match the 1.7.5 code
- Drop upstreamed typecasts patch
- Use patch rather than scripted iconv to fix character encoding of CHANGES
- Fix Source0 URL to point at the upstream tarball
- Fix dist tag for CentOS 6 and Scientific Linux

* Mon Apr 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-3.0.cf
- Apply upstream patch to fix unsafe typecasts (#695424)
- Nobody else likes macros for commands

* Sun Mar 27 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-2.1.cf
- Remove mention of static libraries from %%description of devel package

* Fri Feb 11 2011 Paul Howarth <paul@city-fan.org> - 1.7.4-2.0.cf
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Thu Dec  9 2010 Paul Howarth <paul@city-fan.org> - 1.7.4-1.0.cf
- Update to 1.7.4
  - Support binding to local interface/IPs: see ares_set_local_ip4,
    ares_set_local_ip6, ares_set_local_dev
  - Fix memory leak in ares_getnameinfo
  - Add missing break that caused get_ares_servers to fail
  - Fix CNAME response parsing in ares_parse_a_reply
  - Don't copy an empty sortlist in init_by_options
  - Replace uint32_t with unsigned int to fix broken builds on a couple of
    platforms
  - Fix lookup with HOSTALIASES set
  - Fix NAPTR parsing in adig
  - Compiler warning cleanups
- Drop upstream patches, now included in release

* Wed Aug 25 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-3.0.cf
- Apply fixes from upstream 1.7.4 development:
  - Add missing break that caused get_ares_servers to fail
  - Fix aliasing warning in gcc 4.4.4 (at least)
  - Fix memory leak in ares_getnameinfo

* Tue Jun 15 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-1.1.cf
- Fix multilib file conflict in c-ares-devel (#602880)

* Fri Jun 11 2010 Paul Howarth <paul@city-fan.org> - 1.7.3-1.0.cf
- Update to 1.7.3
  - Builds on Android
  - Now includes all files necessary to build it (1.7.2 lacked a file)

* Thu Jun 10 2010 Paul Howarth <paul@city-fan.org> - 1.7.2-1.0.cf
- Update to 1.7.2
  - Added ares_parse_mx_reply()
  - ares_init: Last, not first instance of domain or search should win
  - Improve alternative definition of bool
  - Fix VS2010 compiler warnings

* Fri May 14 2010 Paul Howarth <paul@city-fan.org> - 1.7.1-2.0.cf
- Fix dist tag for RHEL-6 Beta

* Tue Mar 23 2010 Paul Howarth <paul@city-fan.org> - 1.7.1-1.0.cf
- Update to 1.7.1 (added IPv6 name servers support)
- Drop IPv6 nameserver patch

* Sun Mar  7 2010 Jakub Hrozek <jhrozek@redhat.com> - 1.7.0-3.0.cf
- Change IPv6 nameserver patch according to upstream changes
  (upstream revisions 1199,1201,1202)

* Wed Mar  3 2010 Jakub Hrozek <jhrozek@redhat.com> - 1.7.0-2.0.cf
- Add a patch to allow usage of IPv6 nameservers
- Sync optflags patch with Fedora version

* Tue Dec  1 2009 Paul Howarth <paul@city-fan.org> - 1.7.0-1.0.cf
- Update to 1.7.0 (see RELEASE-NOTES for details)
- New header files ares_build.h and ares_rules.h to package
- Update optflags patch
- Dist tag for Rawhide no longer needs special-casing

* Wed Nov  4 2009 Paul Howarth <paul@city-fan.org> - 1.6.0-3.0.cf
- Import from Fedora
- Drop unbundled LICENSE file
- Add docs RELEASE-NOTES TODO AUTHORS

* Sat Jul 25 2009 Ville Skyttä <ville.skytta at iki.fi> - 1.6.0-3
- Patch to make upstream build system honor our CFLAGS and friends.
- Don't bother building throwaway static libs.
- Disable autotools dependency tracking for cleaner build logs and possible
  slight build speedup.
- Convert docs to UTF-8.
- Update URLs.

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.6.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Wed Jul 22 2009 Tom "spot" Callaway <tcallawa@redhat.com> - 1.6.0-1
- update to 1.6.0

* Mon Feb 23 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 1.5.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Fri Sep 12 2008 Tom "spot" Callaway <tcallawa@redhat.com> - 1.5.3-1
- update to 1.5.3

* Tue Feb 19 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 1.5.1-2
- Autorebuild for GCC 4.3

* Tue Feb 19 2008 Tom "spot" Callaway <tcallawa@redhat.com> 1.5.1-1
- update to 1.5.1

* Thu Aug 23 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.4.0-2
- rebuild for ppc32

* Wed Jun 27 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.4.0-1
- bump to 1.4.0 (resolves bugzilla 243591)
- get rid of static library (.a)

* Wed Jan 17 2007 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.2-1
- bump to 1.3.2

* Mon Sep 11 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.1-2
- FC-6 bump

* Mon Jul 10 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.1-1
- bump to 1.3.1

* Tue Feb 28 2006 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.0-2
- bump for FC-5 rebuild

* Sun Sep  4 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.3.0-1
- include LICENSE text
- bump to 1.3.0

* Tue May 31 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-4
- use dist tag to prevent EVR overlap

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-2
- fix license (MIT, not LGPL)
- get rid of libcares.la

* Fri Apr 22 2005 Tom "spot" Callaway <tcallawa@redhat.com> 1.2.1-1
- initial package creation

